==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkSelectPolyData.java <==
// java wrapper for vtkSelectPolyData object
//

package vtk;
import vtk.*;

public class vtkSelectPolyData extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetGenerateSelectionScalars_2(int id0);
  public void SetGenerateSelectionScalars(int id0)
    { SetGenerateSelectionScalars_2(id0); }

  private native int GetGenerateSelectionScalars_3();
  public int GetGenerateSelectionScalars()
    { return GetGenerateSelectionScalars_3(); }

  private native void GenerateSelectionScalarsOn_4();
  public void GenerateSelectionScalarsOn()
    { GenerateSelectionScalarsOn_4(); }

  private native void GenerateSelectionScalarsOff_5();
  public void GenerateSelectionScalarsOff()
    { GenerateSelectionScalarsOff_5(); }

  private native void SetInsideOut_6(int id0);
  public void SetInsideOut(int id0)
    { SetInsideOut_6(id0); }

  private native int GetInsideOut_7();
  public int GetInsideOut()
    { return GetInsideOut_7(); }

  private native void InsideOutOn_8();
  public void InsideOutOn()
    { InsideOutOn_8(); }

  private native void InsideOutOff_9();
  public void InsideOutOff()
    { InsideOutOff_9(); }

  private native void SetLoop_10(vtkPoints id0);
  public void SetLoop(vtkPoints id0)
    { SetLoop_10(id0); }

  private native long GetLoop_11();
  public vtkPoints GetLoop() {
    long temp = GetLoop_11();

    if (temp == 0) return null;
    return (vtkPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetClosestPoint_12(double id0,double id1,double id2);
  public void SetClosestPoint(double id0,double id1,double id2)
    { SetClosestPoint_12(id0,id1,id2); }

  private native void SetClosestPoint_13(double id0[]);
  public void SetClosestPoint(double id0[])
    { SetClosestPoint_13(id0); }

  private native double[] GetClosestPoint_14();
  public double[] GetClosestPoint()
    { return GetClosestPoint_14(); }

  private native void SetSelectionMode_15(int id0);
  public void SetSelectionMode(int id0)
    { SetSelectionMode_15(id0); }

  private native int GetSelectionModeMinValue_16();
  public int GetSelectionModeMinValue()
    { return GetSelectionModeMinValue_16(); }

  private native int GetSelectionModeMaxValue_17();
  public int GetSelectionModeMaxValue()
    { return GetSelectionModeMaxValue_17(); }

  private native int GetSelectionMode_18();
  public int GetSelectionMode()
    { return GetSelectionMode_18(); }

  private native void SetSelectionModeToSmallestRegion_19();
  public void SetSelectionModeToSmallestRegion()
    { SetSelectionModeToSmallestRegion_19(); }

  private native void SetSelectionModeToLargestRegion_20();
  public void SetSelectionModeToLargestRegion()
    { SetSelectionModeToLargestRegion_20(); }

  private native void SetSelectionModeToClosestPointRegion_21();
  public void SetSelectionModeToClosestPointRegion()
    { SetSelectionModeToClosestPointRegion_21(); }

  private native String GetSelectionModeAsString_22();
  public String GetSelectionModeAsString()
    { return GetSelectionModeAsString_22(); }

  private native void SetGenerateUnselectedOutput_23(int id0);
  public void SetGenerateUnselectedOutput(int id0)
    { SetGenerateUnselectedOutput_23(id0); }

  private native int GetGenerateUnselectedOutput_24();
  public int GetGenerateUnselectedOutput()
    { return GetGenerateUnselectedOutput_24(); }

  private native void GenerateUnselectedOutputOn_25();
  public void GenerateUnselectedOutputOn()
    { GenerateUnselectedOutputOn_25(); }

  private native void GenerateUnselectedOutputOff_26();
  public void GenerateUnselectedOutputOff()
    { GenerateUnselectedOutputOff_26(); }

  private native long GetUnselectedOutput_27();
  public vtkPolyData GetUnselectedOutput() {
    long temp = GetUnselectedOutput_27();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetSelectionEdges_28();
  public vtkPolyData GetSelectionEdges() {
    long temp = GetSelectionEdges_28();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int GetMTime_29();
  public int GetMTime()
    { return GetMTime_29(); }

  public vtkSelectPolyData() { super(); }

  public vtkSelectPolyData(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-18-aarch64.pkg.tar.xz: vtk/vtkSelectPolyData.java <==
// java wrapper for vtkSelectPolyData object
//

package vtk;
import vtk.*;

public class vtkSelectPolyData extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetGenerateSelectionScalars_2(int id0);
  public void SetGenerateSelectionScalars(int id0)
    { SetGenerateSelectionScalars_2(id0); }

  private native int GetGenerateSelectionScalars_3();
  public int GetGenerateSelectionScalars()
    { return GetGenerateSelectionScalars_3(); }

  private native void GenerateSelectionScalarsOn_4();
  public void GenerateSelectionScalarsOn()
    { GenerateSelectionScalarsOn_4(); }

  private native void GenerateSelectionScalarsOff_5();
  public void GenerateSelectionScalarsOff()
    { GenerateSelectionScalarsOff_5(); }

  private native void SetInsideOut_6(int id0);
  public void SetInsideOut(int id0)
    { SetInsideOut_6(id0); }

  private native int GetInsideOut_7();
  public int GetInsideOut()
    { return GetInsideOut_7(); }

  private native void InsideOutOn_8();
  public void InsideOutOn()
    { InsideOutOn_8(); }

  private native void InsideOutOff_9();
  public void InsideOutOff()
    { InsideOutOff_9(); }

  private native void SetLoop_10(vtkPoints id0);
  public void SetLoop(vtkPoints id0)
    { SetLoop_10(id0); }

  private native long GetLoop_11();
  public vtkPoints GetLoop() {
    long temp = GetLoop_11();

    if (temp == 0) return null;
    return (vtkPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetClosestPoint_12(double id0,double id1,double id2);
  public void SetClosestPoint(double id0,double id1,double id2)
    { SetClosestPoint_12(id0,id1,id2); }

  private native void SetClosestPoint_13(double id0[]);
  public void SetClosestPoint(double id0[])
    { SetClosestPoint_13(id0); }

  private native double[] GetClosestPoint_14();
  public double[] GetClosestPoint()
    { return GetClosestPoint_14(); }

  private native void SetSelectionMode_15(int id0);
  public void SetSelectionMode(int id0)
    { SetSelectionMode_15(id0); }

  private native int GetSelectionModeMinValue_16();
  public int GetSelectionModeMinValue()
    { return GetSelectionModeMinValue_16(); }

  private native int GetSelectionModeMaxValue_17();
  public int GetSelectionModeMaxValue()
    { return GetSelectionModeMaxValue_17(); }

  private native int GetSelectionMode_18();
  public int GetSelectionMode()
    { return GetSelectionMode_18(); }

  private native void SetSelectionModeToSmallestRegion_19();
  public void SetSelectionModeToSmallestRegion()
    { SetSelectionModeToSmallestRegion_19(); }

  private native void SetSelectionModeToLargestRegion_20();
  public void SetSelectionModeToLargestRegion()
    { SetSelectionModeToLargestRegion_20(); }

  private native void SetSelectionModeToClosestPointRegion_21();
  public void SetSelectionModeToClosestPointRegion()
    { SetSelectionModeToClosestPointRegion_21(); }

  private native String GetSelectionModeAsString_22();
  public String GetSelectionModeAsString()
    { return GetSelectionModeAsString_22(); }

  private native void SetGenerateUnselectedOutput_23(int id0);
  public void SetGenerateUnselectedOutput(int id0)
    { SetGenerateUnselectedOutput_23(id0); }

  private native int GetGenerateUnselectedOutput_24();
  public int GetGenerateUnselectedOutput()
    { return GetGenerateUnselectedOutput_24(); }

  private native void GenerateUnselectedOutputOn_25();
  public void GenerateUnselectedOutputOn()
    { GenerateUnselectedOutputOn_25(); }

  private native void GenerateUnselectedOutputOff_26();
  public void GenerateUnselectedOutputOff()
    { GenerateUnselectedOutputOff_26(); }

  private native long GetUnselectedOutput_27();
  public vtkPolyData GetUnselectedOutput() {
    long temp = GetUnselectedOutput_27();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelectionEdges_28();
  public vtkPolyData GetSelectionEdges() {
    long temp = GetSelectionEdges_28();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetMTime_29();
  public int GetMTime()
    { return GetMTime_29(); }

  public vtkSelectPolyData() { super(); }

  public vtkSelectPolyData(long id) { super(id); }
  public native long   VTKInit();

}
